@@ -1,9 +1,8 @@
 #' @rdname rfPermute
+#' 
+#' @export rfPermute.formula
 #' @export
-#' @usage \S3method{rfPermute}{formula}(formula, data = NULL, ..., subset, na.action = na.fail, 
-#'   nrep = 100, num.cores = 1)
-
-rfPermute.formula <- function(formula, data = NULL, ..., subset, na.action = na.fail, nrep = 100, num.cores = 1) {
+rfPermute.formula <- function(formula, data = NULL, ..., subset, na.action = na.fail, nrep = 100) {
   if (!inherits(formula, "formula")) stop("method is only for formula objects")
   m <- match.call(expand.dots = FALSE)
   if (any(c("xtest", "ytest") %in% names(m))) stop("xtest/ytest not supported through the formula interface")
